/*	$Id: walkStruct.h 2008/12/09 19:42:53 mallet $ */

/*
 * Copyright (c) 2006,2008 LAAS/CNRS                       --  Tue Jul 25 2006
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */
#ifndef H_GENOM_WALKSTRUCT
#define H_GENOM_WALKSTRUCT

typedef struct WalkName {
  char name[1024];
} WalkName;

typedef struct WalkPosition {
  double xPos;		/**< x position */
  double yPos;		/**< y position */
  double RzPos;		/**< Rz position in degree */
} WalkPosition;


typedef struct WalkFromToPosition {
  WalkPosition fromPosition;
  WalkPosition toPosition;
} WalkFromToPosition ;

typedef struct WALK_XY_ROBOT_BOUNDS_STR {
  double xMin;
  double xMax;
  double yMin;
  double yMax;
} WALK_XY_ROBOT_BOUNDS_STR;

typedef struct WalkInitData {
  WalkName model;
  WALK_XY_ROBOT_BOUNDS_STR bounds;
} WalkInitData;

#define ROBOT_TRAJ_MAX_NB_DOF 50000
typedef struct ROBOT_TRAJ_POSTER_STR {
   int nbDof;
   int nbConfig;
   double dof[ROBOT_TRAJ_MAX_NB_DOF];
} ROBOT_TRAJ_POSTER_STR;



/* --- Magic stuff --------------------------------------------------- */

#define WALK_TARGET_CONFIG_NAME		"walk-target"
#define WALK_TARGET_CONFIG_BUFFER	(500 /*configurations*/)

/* --- Parameters of step generation --------------------------------- */

/*
  These values are optimized for HRP2
*/

/*
  Step length = length of curvilinear abscissa of the center of the box between
  two steps.
*/
#define WALKGEN_STEP_LENGTH             0.2

/*
  Step width = lateral step distance
*/ 
#define WALKGEN_STEP_SPACING            0.2

/*
  Distance below which the centers of two consecutive step should not be
*/
#define WALKGEN_STEP_SECURITY_DISTANCE  0.2

/*
  Lateral enlargement of the bounding box
*/
#define WALKGEN_BOX_LATERAL_TOLERANCE 0.04

#endif /* H_GENOM_WALKSTRUCT */
